@@ -37,33 +37,44 @@ class PipelineSchemaMixin:
         operation["summary"] = operation.pop("description", "")
         return operation
 
-    def get_description(self, path: str, method: HTTPMethod) -> str:
-        serializer = self.get_request_serializer(path, method)
-        description = serializer.__class__.__doc__ or (self.view.__class__.__doc__ or "")
+    def get_description(self, path: str, method: HTTPMethod) -> str:  # pylint: disable=W0613
+        serializer_class = self.view.get_serializer_class()
+        description = serializer_class.__doc__ or (self.view.__class__.__doc__ or "")
         return self._get_description_section(self.view, method, formatting.dedent(smart_str(description)))
 
-    def get_components(self, path: str, method: HTTPMethod) -> Dict[str, Any]:
-        request_serializer = self.get_request_serializer(path, method)
-        response_serializer = self.get_response_serializer(path, method)
+    def get_components(self, path: str, method: HTTPMethod) -> Dict[str, Any]:  # pylint: disable=W0613
+        request_serializer_class = self.view.get_serializer_class()
+        response_serializer_class = self.view.get_serializer_class(output=True)
 
         components = {}
 
-        for serializer in (DetailSerializer(), request_serializer, response_serializer):
+        for serializer_class in (DetailSerializer, request_serializer_class, response_serializer_class):
+            serializer = self.view.initialize_serializer(serializer_class=serializer_class)
+
+            if getattr(serializer, "many", False):
+                serializer = getattr(serializer, "child", serializer)
+
             component_name = self.get_component_name(serializer)
             content = self.map_serializer(serializer)
             components.setdefault(component_name, content)
 
         for method_responses in self.responses.values():
             for serializer_class in method_responses.values():
-                if is_serializer_class(serializer_class):
-                    serializer = self.view.initialize_serializer(serializer_class=serializer_class)
-                    component_name = self.get_component_name(serializer)
-                    content = self.map_serializer(serializer)
-                    components.setdefault(component_name, content)
+                if not is_serializer_class(serializer_class):
+                    continue
+
+                serializer = self.view.initialize_serializer(serializer_class=serializer_class)
+
+                if getattr(serializer, "many", False):
+                    serializer = getattr(serializer, "child", serializer)
+
+                component_name = self.get_component_name(serializer)
+                content = self.map_serializer(serializer)
+                components.setdefault(component_name, content)
 
         return components
 
-    def get_responses(self, path: str, method: HTTPMethod) -> Dict[str, Any]:
+    def get_responses(self, path: str, method: HTTPMethod) -> Dict[str, Any]:  # pylint: disable=W0613
         data = {}
 
         responses = self.responses.get(method, {})
@@ -81,20 +92,38 @@ class PipelineSchemaMixin:
                 info = serializer_class.__doc__ or ""
 
             if info is ...:
-                serializer = self.get_response_serializer(path, method)
-                info = serializer.__class__.__doc__ or ""
-            else:
-                serializer = self.view.initialize_serializer(serializer_class=serializer_class)
+                serializer_class = self.view.get_serializer_class(output=True)
+                info = serializer_class.__doc__ or ""
 
-            schema = self._get_reference(serializer)
+            serializer = self.view.initialize_serializer(serializer_class=serializer_class)
+
+            response_schema = self._get_reference(serializer)
 
             data[str(status_code)] = {
-                "content": {"application/json": {"schema": schema}},
+                "content": {"application/json": {"schema": response_schema}},
                 "description": info,
             }
 
         return data
 
+    def _get_reference(self, serializer: BaseSerializer) -> Dict[str, Any]:
+        if getattr(serializer, "many", False):
+            response_schema = {
+                "type": "array",
+                "items": {
+                    "$ref": f"#/components/schemas/{self.get_component_name(getattr(serializer, 'child', serializer))}"
+                },
+            }
+            paginator = self.get_paginator()
+            if paginator:  # pragma: no cover
+                response_schema = paginator.get_paginated_response_schema(response_schema)
+        else:
+            response_schema = {
+                "$ref": f"#/components/schemas/{self.get_component_name(serializer)}",
+            }
+
+        return response_schema
+
     def get_request_serializer(self, path: str, method: HTTPMethod) -> BaseSerializer:  # pylint: disable=W0613
         return self.view.get_serializer()
 
